import { useRef, useLayoutEffect } from 'react';

var _require = require('text-mask-core'),
    createTextMaskInputElement = _require.createTextMaskInputElement;

function useInputMask(_ref) {
  var guide = _ref.guide,
      inputRef = _ref.input,
      keepCharPositions = _ref.keepCharPositions,
      mask = _ref.mask,
      onChange = _ref.onChange,
      pipe = _ref.pipe,
      placeholderChar = _ref.placeholderChar,
      showMask = _ref.showMask,
      _ref$initialValue = _ref.initialValue,
      initialValue = _ref$initialValue === void 0 ? '' : _ref$initialValue;
  var textMaskRef = useRef(null);
  useLayoutEffect(function () {
    if (!inputRef.current) {
      return;
    }

    textMaskRef.current = createTextMaskInputElement({
      guide: guide,
      inputElement: inputRef.current,
      keepCharPositions: keepCharPositions,
      mask: mask,
      pipe: pipe,
      placeholderChar: placeholderChar,
      showMask: showMask
    });
    textMaskRef.current.update(initialValue);
  }, [inputRef, guide, keepCharPositions, mask, pipe, placeholderChar, showMask, initialValue]);
  return function (event) {
    if (textMaskRef.current) {
      textMaskRef.current.update();
    }

    if (typeof onChange === 'function') {
      onChange(event);
    }
  };
}

export default useInputMask;
